import ContainerWrapper from '../ContainerWrapper';
import actionName from '../../utils/actionName';

import datepickerChange from './redux/datepickerChange';
import datepickerCollapse from './redux/datepickerCollapse';
import datepickerExpand from './redux/datepickerExpand';
import datepickerHighlightedIndexChange from './redux/datepickerHighlightedIndexChange';


export const changeType = actionName('CHANGE');
export const collapseType = actionName('COLLAPSE');
export const expandType = actionName('EXPAND');
export const highlightedIndexChangeType = actionName('SELECTED-INDEX-CHANGE');

export default ({
    Component
} = {}) => {

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DATEPICKER';

        return {
            onChange: (currentMonth, highlightedIndex, value) => dispatch(datepickerChange({ currentMonth, custom, highlightedIndex, path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: (currentMonth, highlightedIndex) => dispatch(datepickerCollapse({ currentMonth, highlightedIndex, path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(datepickerExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (currentMonth, highlightedIndex) => dispatch(datepickerHighlightedIndexChange({ currentMonth, highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return ContainerWrapper({
        Component,
        mapDispatchToProps
    });

};
