import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import datepickerState from './redux/datepickerState';


export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Datepicker component.');

    return React.createClass({

        displayName: `${Component.displayName}`,

        mixins: [PureRenderMixin],

        propTypes: {
            onChange: PropTypes.func,
            initialValue: PropTypes.number
        },

        getDefaultProps() {
            return {
                onChange: (/* value */) => {},
                initialValue: null
            };
        },

        getInitialState() {
            const { initialValue } = this.props;
            const { currentMonth, expanded, highlightedIndex, value } = datepickerState({ value: initialValue });

            return {
                currentMonth,
                expanded,
                highlightedIndex,
                value
            };
        },

        onChange(currentMonth, highlightedIndex, value) {
            this.setState({ currentMonth, expanded: false, highlightedIndex, value },
                () => this.props.onChange(value));
        },

        onCollapse(currentMonth, highlightedIndex) {
            this.setState({ currentMonth, expanded: false, highlightedIndex });
        },

        onExpand() {
            this.setState({ expanded: true });
        },

        onHighlightedIndexChange(currentMonth, highlightedIndex) {
            this.setState({ currentMonth, highlightedIndex });
        },

        render() {
            return (
                <Component
                    { ...this.props }
                    { ...this.state }
                    onChange={ this.onChange }
                    onCollapse={ this.onCollapse }
                    onExpand={ this.onExpand }
                    onHighlightedIndexChange={ this.onHighlightedIndexChange } />
            );
        }

    });

};
