import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import purebem from 'purebem';

import FoundationClickOutside from '../misc/FoundationClickOutside';
import FoundationInformation from './FoundationInformation';
import FoundationOverlayLayout from './FoundationOverlayLayout';

import './FoundationLightbox.less';


const block = purebem.of('foundation-lightbox');

const FoundationLightbox = React.createClass({

    mixins: [PureRenderMixin],

    propTypes: {
        disableClose: PropTypes.bool,
        name: PropTypes.string,
        components: PropTypes.object,
        hasNavigation: PropTypes.bool,
        location: PropTypes.object,
        onClose: PropTypes.func,
        props: PropTypes.object
    },

    getDefaultProps() {
        return {
            disableClose: false,
            hasNavigation: true,
            name: '',
            onClose: () => {},
            props: {}
        };
    },

    componentDidUpdate(prevProps) {
        // might need to include query in here as well.
        if (this.props.location.pathname !== prevProps.location.pathname) {
            // we always want to close when we navigate regardless of `disableClose`.
            this.props.onClose();
        }
    },

    getLightboxComponent() {
        const { components, name } = this.props;

        const component = components[name];
        const style = { backgroundColor: '#e6726a', color: '#fff', minHeight: '100%', padding: '20px' };

        switch (name) {
            case 'information':
                return FoundationInformation;

            default:
                if (component) {
                    return component;
                }

                return () => (<div style={ style }>{ `Missing lightbox component: could not find component for \`${name}\`.` }</div>);
        }
    },

    onClose() {
        const { disableClose, onClose } = this.props;
        if (disableClose) {
            return;
        }

        onClose();
    },

    renderLightbox() {
        const { hasNavigation, props } = this.props;
        const Component = this.getLightboxComponent();

        return (
            <FoundationOverlayLayout
                hasNavigation={ hasNavigation }>
                <FoundationClickOutside
                    onClick={ this.onClose }>
                    <div className={ block() }>
                        <Component
                            { ...props }
                            onClose={ this.onClose } />
                    </div>
                </FoundationClickOutside>
            </FoundationOverlayLayout>
        );
    },

    render() {
        const { name } = this.props;
        if (name === null) {
            return null;
        }

        return this.renderLightbox();
    }

});

export default FoundationLightbox;
