import toNumber from './toNumber';


test('float: non-number as string', () => {
    const result = toNumber('x', 'float');
    expect(result).toEqual({ value: '', valid: false });
});

test('float: number as string', () => {
    const result = toNumber('1', 'float');
    expect(result).toEqual({ value: 1, valid: true });
});

test('float: comma', () => {
    const result = toNumber('11,11', 'float');
    expect(result).toEqual({ value: 11.11, valid: true });
});

test('float: dot', () => {
    const result = toNumber('11.11', 'float');
    expect(result).toEqual({ value: 11.11, valid: true });
});

test('float: minus', () => {
    const result = toNumber('-', 'float');
    expect(result).toEqual({ value: 0, valid: true });
});

test('float: multiple minuses', () => {
    const result = toNumber('--', 'float');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer: non-number as string', () => {
    const result = toNumber('x', 'integer');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer: number as string', () => {
    const result = toNumber('1', 'integer');
    expect(result).toEqual({ value: 1, valid: true });
});

test('integer: negative number as string', () => {
    const result = toNumber('-1', 'integer');
    expect(result).toEqual({ value: -1, valid: true });
});

test('integer: comma', () => {
    const result = toNumber('11,11', 'integer');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer: dot', () => {
    const result = toNumber('11.11', 'integer');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer: minus', () => {
    const result = toNumber('-', 'integer');
    expect(result).toEqual({ value: 0, valid: true });
});

test('integer: multiple minuses', () => {
    const result = toNumber('--', 'integer');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer-positive-only: negative number (-1) as string', () => {
    const result = toNumber('-1', 'integer-positive-only');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer-positive-only: number (0) as string', () => {
    const result = toNumber('0', 'integer-positive-only');
    expect(result).toEqual({ value: 0, valid: true });
});

test('integer-positive-only: number (1) as string', () => {
    const result = toNumber('1', 'integer-positive-only');
    expect(result).toEqual({ value: 1, valid: true });
});

test('integer-positive-only: non-number as string', () => {
    const result = toNumber('x', 'integer-positive-only');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer-positive-only: number as string', () => {
    const result = toNumber('1', 'integer-positive-only');
    expect(result).toEqual({ value: 1, valid: true });
});

test('integer-positive-only: comma', () => {
    const result = toNumber('11,11', 'integer-positive-only');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer-positive-only: dot', () => {
    const result = toNumber('11.11', 'integer-positive-only');
    expect(result).toEqual({ value: '', valid: false });
});

test('integer: minus', () => {
    const result = toNumber('-', 'integer-positive-only');
    expect(result).toEqual({ value: '', valid: false });
});
